[patch 40/43] rename del_ktimeout_sync() to del_ktimeout_sync()

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



plain text document attachment (ktimeout-rename-ktimeout_del_sync.patch)
- rename del_ktimeout_sync() to del_ktimeout_sync()

Signed-off-by: Ingo Molnar <[email protected]>

 include/linux/ktimeout.h |    6 +++---
 include/linux/timer.h    |    2 +-
 kernel/ktimeout.c        |    8 ++++----
 3 files changed, 8 insertions(+), 8 deletions(-)

Index: linux/include/linux/ktimeout.h
===================================================================
--- linux.orig/include/linux/ktimeout.h
+++ linux/include/linux/ktimeout.h
@@ -89,13 +89,13 @@ static inline void ktimeout_add(struct k
 
 #ifdef CONFIG_SMP
   extern int ktimeout_try_to_del_sync(struct ktimeout *ktimeout);
-  extern int del_ktimeout_sync(struct ktimeout *ktimeout);
+  extern int ktimeout_del_sync(struct ktimeout *ktimeout);
 #else
 # define ktimeout_try_to_del_sync(t)	ktimeout_del(t)
-# define del_ktimeout_sync(t)		ktimeout_del(t)
+# define ktimeout_del_sync(t)		ktimeout_del(t)
 #endif
 
-#define del_singleshot_ktimeout_sync(t) del_ktimeout_sync(t)
+#define del_singleshot_ktimeout_sync(t) ktimeout_del_sync(t)
 
 extern void init_ktimeouts(void);
 extern void run_local_ktimeouts(void);
Index: linux/include/linux/timer.h
===================================================================
--- linux.orig/include/linux/timer.h
+++ linux/include/linux/timer.h
@@ -26,7 +26,7 @@
 #define next_timer_interrupt		ktimeout_next_interrupt
 #define add_timer			ktimeout_add
 #define try_to_del_timer_sync		ktimeout_try_to_del_sync
-#define del_timer_sync			del_ktimeout_sync
+#define del_timer_sync			ktimeout_del_sync
 #define del_singleshot_timer_sync	del_singleshot_ktimeout_sync
 #define init_timers			init_ktimeouts
 #define run_local_timers		run_local_ktimeouts
Index: linux/kernel/ktimeout.c
===================================================================
--- linux.orig/kernel/ktimeout.c
+++ linux/kernel/ktimeout.c
@@ -211,7 +211,7 @@ int __ktimeout_mod(struct ktimeout *ktim
 		/*
 		 * We are trying to schedule the timeout on the local CPU.
 		 * However we can't change timeout's base while it is running,
 		 * otherwise del_ktimeout_sync() can't detect that the timeout's
 		 * handler yet has not finished. This also guarantees that
 		 * the timeout is serialized wrt itself.
 		 */
@@ -353,7 +353,7 @@ out:
 }
 
 /***
  * del_ktimeout_sync - deactivate a timeout and wait for the handler to finish.
  * @ktimeout: the timeout to be deactivated
  *
  * This function only differs from ktimeout_del() on SMP: besides deactivating
@@ -369,7 +369,7 @@ out:
  *
  * The function returns whether it has deactivated a pending timeout or not.
  */
-int del_ktimeout_sync(struct ktimeout *ktimeout)
+int ktimeout_del_sync(struct ktimeout *ktimeout)
 {
 	for (;;) {
 		int ret = ktimeout_try_to_del_sync(ktimeout);
@@ -378,7 +378,7 @@ int del_ktimeout_sync(struct ktimeout *k
 	}
 }
 
-EXPORT_SYMBOL(del_ktimeout_sync);
+EXPORT_SYMBOL(ktimeout_del_sync);
 #endif
 
 static int cascade(tvec_base_t *base, tvec_t *tv, int index)
@@ -211,7 +211,7 @@ int __ktimeout_mod(struct ktimeout *ktim
 		 * We are trying to schedule the timeout on the local CPU.
 		 * However we can't change timeout's base while it is running,
-		 * otherwise del_ktimeout_sync() can't detect that the timeout's
+		 * otherwise ktimeout_del_sync() can't detect that the timeout's
 		 * handler yet has not finished. This also guarantees that
 		 * the timeout is serialized wrt itself.
@@ -353,7 +353,7 @@ out:
 
 /***
- * del_ktimeout_sync - deactivate a timeout and wait for the handler to finish.
+ * ktimeout_del_sync - deactivate a timeout and wait for the handler to finish.
  * @ktimeout: the timeout to be deactivated
  *

--

-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to [email protected]
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

[Index of Archives]     [Kernel Newbies]     [Netfilter]     [Bugtraq]     [Photo]     [Stuff]     [Gimp]     [Yosemite News]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Video 4 Linux]     [Linux for the blind]     [Linux Resources]
  Powered by Linux